save_buffer

Function save_buffer 

pub fn save_buffer(path: impl AsRef<Path>, buffer: &TextBuffer) -> Result<()>
Write a TextBuffer to a UTF-8 file.

This writes the entire buffer to disk in one go. Will add variants later for stuff like incremental or atomic writes.