pub enum Motion {
}Expand description
A navigation intent (motion) that transforms a document cursor.
Variants
Left
Move left by one char.
Right
Move right by one char.
Up
Move up by one line.
Down
Move down by one line.
FileStart
Go to first line of file (gg).
FileEnd
Go to last line of file (G). Column is clamped to that line.
LineStart
Go to start of line (0-ish).
LineFirstNonWhitespace
Go to the first non-whitespace character on the line (_-ish).
LineEnd
Go to end of line ($-ish), i.e. line_len_chars(line).
WordStartBefore
Move to start of previous word (b-ish).
WordStartAfter
Move to start of next word (w-ish).
WordEndAfter
Move to end of next word (e-ish).
FindChar(char)
Move onto the next matching character on the current line (f-ish).
TillChar(char)
Move just before the next matching character on the current line (t-ish).
FindCharBefore(char)
Move onto the previous matching character on the current line (F-ish).
TillCharBefore(char)
Move just after the previous matching character on the current line (T-ish).
MatchDelimiter
Jump to the delimiter paired with the delimiter under the cursor (%-ish).