pub fn save_buffer(path: impl AsRef<Path>, buffer: &TextBuffer) -> Result<()>Expand description
Write a TextBuffer to a UTF-8 file.
This writes the entire buffer to disk in one go. Will add variants later for stuff like incremental or atomic writes.